View source: R/betaSandwich-beta-hc.R
| BetaHC | R Documentation |
Estimate Standardized Regression Coefficients and the Corresponding Robust Sampling Covariance Matrix Using the Heteroskedasticity Consistent Approach
BetaHC(
object,
type = "hc3",
alpha = c(0.05, 0.01, 0.001),
g1 = 1,
g2 = 1.5,
k = 0.7
)
object |
Object of class |
type |
Character string.
Correction type.
Possible values are
|
alpha |
Numeric vector.
Significance level |
g1 |
Numeric.
|
g2 |
Numeric.
|
k |
Numeric.
Constant |
Returns an object
of class betasandwich which is a list with the following elements:
Function call.
Function arguments.
Processed lm object.
Asymptotic covariance matrix of the sample covariance matrix assuming multivariate normality.
Asymptotic covariance matrix HC correction.
Asymptotic covariance matrix of the sample covariance matrix.
Asymptotic covariance matrix of the standardized slopes.
Sampling covariance matrix of the standardized slopes.
Vector of standardized slopes.
Ivan Jacob Agaloos Pesigan
Dudgeon, P. (2017). Some improvements in confidence intervals for standardized regression coefficients. Psychometrika, 82(4), 928–951. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11336-017-9563-z")}
Pesigan, I. J. A., Sun, R. W., & Cheung, S. F. (2023). betaDelta and betaSandwich: Confidence intervals for standardized regression coefficients in R. Multivariate Behavioral Research. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/00273171.2023.2201277")}
Other Beta Sandwich Functions:
BetaADF(),
BetaN(),
DiffBetaSandwich(),
RSqBetaSandwich()
object <- lm(QUALITY ~ NARTIC + PCTGRT + PCTSUPP, data = nas1982)
std <- BetaHC(object)
# Methods -------------------------------------------------------
print(std)
summary(std)
coef(std)
vcov(std)
confint(std, level = 0.95)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.