betaSandwich-package: betaSandwich: Robust Confidence Intervals for Standardized...

betaSandwich-packageR Documentation

betaSandwich: Robust Confidence Intervals for Standardized Regression Coefficients

Description

Generates robust confidence intervals for standardized regression coefficients using heteroskedasticity-consistent standard errors for models fitted by lm() as described in Dudgeon (2017) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11336-017-9563-z")}. The package can also be used to generate confidence intervals for R-squared, adjusted R-squared, and differences of standardized regression coefficients. A description of the package and code examples are presented in Pesigan, Sun, and Cheung (2023) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/00273171.2023.2201277")}.

Author(s)

Maintainer: Ivan Jacob Agaloos Pesigan r.jeksterslab@gmail.com (ORCID) [copyright holder]

Authors:

See Also

Useful links:


betaSandwich documentation built on June 12, 2026, 1:06 a.m.