Learn R Programming

betaSandwich (version 1.0.8)

confint.rsqbetasandwich: Confidence Intervals for Multiple Correlation Coefficients (R-Squared and Adjusted R-Squared)

Description

Confidence Intervals for Multiple Correlation Coefficients (R-Squared and Adjusted R-Squared)

Usage

# S3 method for rsqbetasandwich
confint(object, parm = NULL, level = 0.95, ...)

Value

Returns a matrix of confidence intervals.

Arguments

object

Object of class rsqbetasandwich.

parm

a specification of which parameters are to be given confidence intervals, either a vector of numbers or a vector of names. If missing, all parameters are considered.

level

the confidence level required.

...

additional arguments.

Author

Ivan Jacob Agaloos Pesigan

Examples

Run this code
object <- lm(QUALITY ~ NARTIC + PCTGRT + PCTSUPP, data = nas1982)
std <- BetaHC(object)
rsq <- RSqBetaSandwich(std)
confint(rsq, level = 0.95)

Run the code above in your browser using DataLab