Learn R Programming

betaSandwich (version 1.0.8)

vcov.diffbetasandwich: Sampling Covariance Matrix of Differences of Standardized Regression Slopes

Description

Sampling Covariance Matrix of Differences of Standardized Regression Slopes

Usage

# S3 method for diffbetasandwich
vcov(object, ...)

Value

Returns a matrix of the variance-covariance matrix of differences of standardized regression slopes.

Arguments

object

Object of class diffbetasandwich.

...

additional arguments.

Author

Ivan Jacob Agaloos Pesigan

Examples

Run this code
object <- lm(QUALITY ~ NARTIC + PCTGRT + PCTSUPP, data = nas1982)
std <- BetaHC(object)
diff <- DiffBetaSandwich(std)
vcov(diff)

Run the code above in your browser using DataLab