Learn R Programming

betaSandwich (version 1.0.8)

betaSandwich-package: betaSandwich: Robust Confidence Intervals for Standardized Regression Coefficients

Description

Generates robust confidence intervals for standardized regression coefficients using heteroskedasticity-consistent standard errors for models fitted by lm() as described in Dudgeon (2017) tools:::Rd_expr_doi("10.1007/s11336-017-9563-z"). The package can also be used to generate confidence intervals for R-squared, adjusted R-squared, and differences of standardized regression coefficients. A description of the package and code examples are presented in Pesigan, Sun, and Cheung (2023) tools:::Rd_expr_doi("10.1080/00273171.2023.2201277").

Arguments

Author

Maintainer: Ivan Jacob Agaloos Pesigan r.jeksterslab@gmail.com (ORCID) [copyright holder]

See Also