powered by
Confidence Intervals for Multiple Correlation Coefficients (R-Squared and Adjusted R-Squared)
# S3 method for rsqbetasandwich confint(object, parm = NULL, level = 0.95, ...)
Returns a matrix of confidence intervals.
Object of class rsqbetasandwich.
rsqbetasandwich
a specification of which parameters are to be given confidence intervals, either a vector of numbers or a vector of names. If missing, all parameters are considered.
the confidence level required.
additional arguments.
Ivan Jacob Agaloos Pesigan
object <- lm(QUALITY ~ NARTIC + PCTGRT + PCTSUPP, data = nas1982) std <- BetaHC(object) rsq <- RSqBetaSandwich(std) confint(rsq, level = 0.95)
Run the code above in your browser using DataLab